//#define LPL

#ifdef LPL
#include <RFM69.h>
#else
#include "Radio.h"
#endif
#include <avr/wdt.h>
#include <MsTimer2.h>

#define TX_FREQ 10000

#define UNKNOWN 0x0
#define HEURES_PLEINES 0x1
#define HEURES_CREUSES 0x2

#define NODE_ID 19

// U,U
typedef struct
{
    uint32_t test1;
    uint32_t test2;
} Payload;
Payload payload = {100,200};

// Must be between 0 & 7
#define PIN_LED_1 3
#define PIN_LED_2 4

#ifdef LPL
RFM69 radio;
#else
Radio radio;
#endif

unsigned long lastTx = 0ul;
volatile uint8_t ledCount;

void emonSend(Payload *payload);
void ledOff();
void blink(uint8_t count);

void setup()
{
    Serial.begin(9600);
    wdt_enable(WDTO_4S);
    Serial.println("Initializing radio...");
#ifdef LPL
    if (! radio.initialize(RF69_433MHZ, NODE_ID, 210)) {
        Serial.println("Radio initialization failed!");
        delay(3000);
    }
#else
    radio.init(NODE_ID);
#endif
    wdt_reset();
    Serial.println("done.");

    pinMode(PIN_LED_1, OUTPUT);
    pinMode(PIN_LED_2, OUTPUT);
    MsTimer2::set(250, ledOff);

    for (int i = 0; i < 4; i++) {
        digitalWrite(PIN_LED_1, HIGH);
        delay(250);
        digitalWrite(PIN_LED_1, LOW);
        delay(250);
    }

    blink(2);
}

void blink(uint8_t count)
{
    ledCount = count + 1;
    digitalWrite(PIN_LED_2, HIGH);
    MsTimer2::start();
}


void ledOff()
{
    PORTD ^= _BV(PIN_LED_2);
    if (--ledCount == 0) {
          MsTimer2::stop();
    }
}

void loop()
{
    wdt_reset();
    if (millis() - lastTx > TX_FREQ) {
        emonSend(&payload);
        payload.test1 += 1;
        payload.test2 += 1;
        Serial.println("sent.");
        lastTx = millis();
    }
}

void emonSend(Payload *payload)
{
    Serial.print("Sending "); Serial.print(sizeof(Payload)); Serial.println(" bytes");
#ifdef LPL
    radio.send(255, payload, sizeof(Payload));
#else
    radio.send(payload, sizeof(Payload));
#endif
    wdt_reset();
    delay(200);
}
